package betterquesting.commands.admin;

import betterquesting.api.api.QuestingAPI;
import betterquesting.api.properties.NativeProps;
import betterquesting.commands.QuestCommandBase;
import betterquesting.network.handlers.NetLifeSync;
import betterquesting.storage.LifeDatabase;
import betterquesting.storage.NameCache;
import betterquesting.storage.QuestSettings;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.UUID;
import net.minecraft.command.CommandBase;
import net.minecraft.command.ICommandSender;
import net.minecraft.entity.player.EntityPlayerMP;
import net.minecraft.server.MinecraftServer;
import net.minecraft.util.ChatComponentTranslation;

/* loaded from: betterquesting_commands_admin.jar:betterquesting/commands/admin/QuestCommandLives.class */
public class QuestCommandLives extends QuestCommandBase {
    public String getCommand() {
        return "lives";
    }

    public String getUsageSuffix() {
        return "[add|set|max|default] <value> [username|uuid]";
    }

    public boolean validArgs(String[] args) {
        return args.length == 4 || args.length == 3;
    }

    public List<String> autoComplete(MinecraftServer server, ICommandSender sender, String[] args) {
        List<String> list = new ArrayList<>();
        if (args.length == 4 && (args[1].equalsIgnoreCase("add") || args[1].equalsIgnoreCase("set"))) {
            return CommandBase.func_71530_a(args, (String[]) NameCache.INSTANCE.getAllNames().toArray(new String[0]));
        }
        if (args.length == 2) {
            return CommandBase.func_71530_a(args, new String[]{"add", "set", "max", "default"});
        }
        return list;
    }

    public void runCommand(MinecraftServer server, CommandBase command, ICommandSender sender, String[] args) {
        String action = args[1];
        UUID playerID = null;
        try {
            int value = Integer.parseInt(args[2]);
            if (args.length >= 4) {
                playerID = findPlayerID(server, sender, args[3]);
                if (playerID == null) {
                    throw getException(command);
                }
            }
            String pName = playerID == null ? "NULL" : NameCache.INSTANCE.getName(playerID);
            if (action.equalsIgnoreCase("set")) {
                int value2 = Math.max(1, value);
                if (playerID != null) {
                    LifeDatabase.INSTANCE.setLives(playerID, value2);
                    EntityPlayerMP target = null;
                    Iterator it = server.func_71203_ab().field_72404_b.iterator();
                    while (true) {
                        if (!it.hasNext()) {
                            break;
                        }
                        EntityPlayerMP p = (EntityPlayerMP) it.next();
                        if (p.func_146103_bH().getId().equals(playerID)) {
                            target = p;
                            break;
                        }
                    }
                    if (target != null) {
                        NetLifeSync.sendSync(new EntityPlayerMP[]{target}, new UUID[]{playerID});
                    }
                    sender.func_145747_a(new ChatComponentTranslation("betterquesting.cmd.lives.set_player", new Object[]{pName, Integer.valueOf(value2)}));
                    return;
                }
                for (EntityPlayerMP p2 : server.func_71203_ab().field_72404_b) {
                    UUID uuid = QuestingAPI.getQuestingUUID(p2);
                    LifeDatabase.INSTANCE.setLives(uuid, value2);
                    NetLifeSync.sendSync(new EntityPlayerMP[]{p2}, new UUID[]{uuid});
                }
                sender.func_145747_a(new ChatComponentTranslation("betterquesting.cmd.lives.set_all", new Object[]{Integer.valueOf(value2)}));
                return;
            }
            if (action.equalsIgnoreCase("add")) {
                if (playerID != null) {
                    int lives = LifeDatabase.INSTANCE.getLives(playerID) + value;
                    LifeDatabase.INSTANCE.setLives(playerID, lives);
                    EntityPlayerMP target2 = null;
                    Iterator it2 = server.func_71203_ab().field_72404_b.iterator();
                    while (true) {
                        if (!it2.hasNext()) {
                            break;
                        }
                        EntityPlayerMP p3 = (EntityPlayerMP) it2.next();
                        if (p3.func_146103_bH().getId().equals(playerID)) {
                            target2 = p3;
                            break;
                        }
                    }
                    if (target2 != null) {
                        NetLifeSync.sendSync(new EntityPlayerMP[]{target2}, new UUID[]{playerID});
                    }
                    if (value >= 0) {
                        sender.func_145747_a(new ChatComponentTranslation("betterquesting.cmd.lives.add_player", new Object[]{Integer.valueOf(value), pName, Integer.valueOf(lives)}));
                        return;
                    } else {
                        sender.func_145747_a(new ChatComponentTranslation("betterquesting.cmd.lives.remove_player", new Object[]{Integer.valueOf(Math.abs(value)), pName, Integer.valueOf(lives)}));
                        return;
                    }
                }
                for (EntityPlayerMP p4 : server.func_71203_ab().field_72404_b) {
                    UUID uuid2 = QuestingAPI.getQuestingUUID(p4);
                    LifeDatabase.INSTANCE.setLives(uuid2, LifeDatabase.INSTANCE.getLives(uuid2) + value);
                    NetLifeSync.sendSync(new EntityPlayerMP[]{p4}, new UUID[]{uuid2});
                }
                if (value >= 0) {
                    sender.func_145747_a(new ChatComponentTranslation("betterquesting.cmd.lives.add_all", new Object[]{Integer.valueOf(value)}));
                    return;
                } else {
                    sender.func_145747_a(new ChatComponentTranslation("betterquesting.cmd.lives.remove_all", new Object[]{Integer.valueOf(Math.abs(value))}));
                    return;
                }
            }
            if (action.equalsIgnoreCase("max")) {
                int value3 = Math.max(1, value);
                QuestSettings.INSTANCE.setProperty(NativeProps.LIVES_MAX, Integer.valueOf(value3));
                sender.func_145747_a(new ChatComponentTranslation("betterquesting.cmd.lives.max", new Object[]{Integer.valueOf(value3)}));
            } else {
                if (action.equalsIgnoreCase("default")) {
                    int value4 = Math.max(1, value);
                    QuestSettings.INSTANCE.setProperty(NativeProps.LIVES_DEF, Integer.valueOf(value4));
                    sender.func_145747_a(new ChatComponentTranslation("betterquesting.cmd.lives.default" + value4, new Object[0]));
                    return;
                }
                throw getException(command);
            }
        } catch (Exception e) {
            throw getException(command);
        }
    }

    public boolean isArgUsername(String[] args, int index) {
        return index == 3;
    }
}
